==> com.liferay.frontend.editor.tinymce.web-5.0.2.jar: META-INF/resources/_diffs/langs/cs.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('cs', {
	Cut: 'Vyjmout',
	'Heading 5': 'Nadpis 5',
	'Header 2': 'Nadpis 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'V\u00e1\u0161 prohl\u00ed\u017ee\u010d nepodporuje p\u0159\u00edm\u00fd p\u0159\u00edstup do schr\u00e1nky. Pou\u017eijte pros\u00edm kl\u00e1vesov\u00e9 zkratky Ctrl+X/C/V.',
	'Heading 4': 'Nadpis 4',
	Div: 'Div (blok)',
	'Heading 2': 'Nadpis 2',
	Paste: 'Vlo\u017eit',
	Close: 'Zav\u0159\u00edt',
	'Font Family': 'Typ p\u00edsma',
	Pre: 'Pre (p\u0159edform\u00e1tov\u00e1no)',
	'Align right': 'Zarovnat vpravo',
	'New document': 'Nov\u00fd dokument',
	Blockquote: 'Citace',
	'Numbered list': '\u010c\u00edslov\u00e1n\u00ed',
	'Heading 1': 'Nadpis 1',
	Headings: 'Nadpisy',
	'Increase indent': 'Zv\u011bt\u0161it odsazen\u00ed',
	Formats: 'Form\u00e1ty',
	Headers: 'Nadpisy',
	'Select all': 'Vybrat v\u0161e',
	'Header 3': 'Nadpis 3',
	Blocks: 'Blokov\u00e9 zobrazen\u00ed (block)',
	Undo: 'Zp\u011bt',
	Strikethrough: 'P\u0159e\u0161rktnut\u00e9',
	'Bullet list': 'Odr\u00e1\u017eky',
	'Header 1': 'Nadpis 1',
	Superscript: 'Horn\u00ed index',
	'Clear formatting': 'Vymazat form\u00e1tov\u00e1n\u00ed',
	'Font Sizes': 'Velikost p\u00edsma',
	Subscript: 'Doln\u00ed index',
	'Header 6': 'Nadpis 6',
	Redo: 'Znovu',
	Paragraph: 'Odstavec',
	Ok: 'OK',
	Bold: 'Tu\u010dn\u00e9',
	Code: 'Code (k\u00f3d)',
	Italic: 'Kurz\u00edva',
	'Align center': 'Zarovnat na st\u0159ed',
	'Header 5': 'Nadpis 5',
	'Heading 6': 'Nadpis 6',
	'Heading 3': 'Nadpis 3',
	'Decrease indent': 'Zmen\u0161it odsazen\u00ed',
	'Header 4': 'Nadpis 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Je zapnuto vkl\u00e1d\u00e1n\u00ed \u010dist\u00e9ho textu. Dokud nebude tato volba vypnuta, bude ve\u0161ker\u00fd obsah vlo\u017een jako \u010dist\u00fd text.',
	Underline: 'Podtr\u017een\u00e9',
	Cancel: 'Zru\u0161it',
	Justify: 'Zarovnat do bloku',
	Inline: '\u0158\u00e1dkov\u00e9 zobrazen\u00ed (inline)',
	Copy: 'Kop\u00edrovat',
	'Align left': 'Zarovnat vlevo',
	'Visual aids': 'Vizu\u00e1ln\u00ed pom\u016fcky',
	'Lower Greek': 'Mal\u00e9 p\u00edsmenkov\u00e1n\u00ed',
	Square: '\u010ctvere\u010dek',
	Default: 'V\u00fdchoz\u00ed',
	'Lower Alpha': 'Norm\u00e1ln\u00ed \u010d\u00edslov\u00e1n\u00ed',
	Circle: 'Kole\u010dko',
	Disc: 'Punt\u00edk',
	'Upper Alpha': 'velk\u00e9 p\u00edsmenkov\u00e1n\u00ed',
	'Upper Roman': '\u0158\u00edmsk\u00e9 \u010d\u00edslice',
	'Lower Roman': 'Mal\u00e9 \u0159\u00edmsk\u00e9 \u010d\u00edslice',
	Name: 'N\u00e1zev',
	Anchor: 'Kotva',
	'You have unsaved changes are you sure you want to navigate away?':
		'M\u00e1te neulo\u017een\u00e9 zm\u011bny. Opravdu chcete opustit str\u00e1nku?',
	'Restore last draft': 'Obnovit posledn\u00ed koncept',
	'Special character': 'Speci\u00e1ln\u00ed znak',
	'Source code': 'Zdrojov\u00fd k\u00f3d',
	Color: 'Barva',
	'Right to left': 'Zprava doleva',
	'Left to right': 'Zleva doprava',
	Emoticons: 'Emotikony',
	Robots: 'Roboti',
	'Document properties': 'Vlastnosti dokumentu',
	Title: 'Titulek',
	Keywords: 'Kl\u00ed\u010dov\u00e1 slova',
	Encoding: 'K\u00f3dov\u00e1n\u00ed',
	Description: 'Popis',
	Author: 'Autor',
	Fullscreen: 'Na celou obrazovku',
	'Horizontal line': 'Vodorovn\u00e1 \u010d\u00e1ra',
	'Horizontal space': 'Horizont\u00e1ln\u00ed mezera',
	'Insert/edit image': 'Vlo\u017eit / upravit obr\u00e1zek',
	General: 'Obecn\u00e9',
	Advanced: 'Pokro\u010dil\u00e9',
	Source: 'URL',
	Border: 'R\u00e1me\u010dek',
	'Constrain proportions': 'Zachovat proporce',
	'Vertical space': 'Vertik\u00e1ln\u00ed mezera',
	'Image description': 'Popis obr\u00e1zku',
	Style: 'Styl',
	Dimensions: 'Rozm\u011bry',
	'Insert image': 'Vlo\u017eit obr\u00e1zek',
	'Insert date/time': 'Vlo\u017eit datum / \u010das',
	'Remove link': 'Odstranit odkaz',
	Url: 'URL',
	'Text to display': 'Text k zobrazen\u00ed',
	Anchors: 'Kotvy',
	'Insert link': 'Vlo\u017eit odkaz',
	'New window': 'Nov\u00e9 okno',
	None: '\u017d\u00e1dn\u00e9',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Zadan\u00e9 URL vypad\u00e1 jako odkaz na jin\u00fd web. Chcete doplnit povinn\u00fd prefix http://?',
	Target: 'C\u00edl',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Zadan\u00e9 URL vypad\u00e1 jako e-mailov\u00e1 adresa. Chcete doplnit povinn\u00fd prefix mailto:?',
	'Insert/edit link': 'Vlo\u017eit / upravit odkaz',
	'Insert/edit video': 'Vlo\u017eit / upravit video',
	Poster: 'N\u00e1hled',
	'Alternative source': 'Alternativn\u00ed zdroj',
	'Paste your embed code below:':
		'Vlo\u017ete k\u00f3d pro vlo\u017een\u00ed n\u00ed\u017ee:',
	'Insert video': 'Vlo\u017eit video',
	Embed: 'Vlo\u017eit',
	'Nonbreaking space': 'Pevn\u00e1 mezera',
	'Page break': 'Konec str\u00e1nky',
	'Paste as text': 'Vlo\u017eit jako \u010dist\u00fd text',
	Preview: 'N\u00e1hled',
	Print: 'Tisk',
	Save: 'Ulo\u017eit',
	'Could not find the specified string.':
		'Zadan\u00fd \u0159et\u011bzec nebyl nalezen.',
	Replace: 'Nahradit',
	Next: 'Dal\u0161\u00ed',
	'Whole words': 'Pouze cel\u00e1 slova',
	'Find and replace': 'Naj\u00edt a nahradit',
	'Replace with': 'Nahradit za',
	Find: 'Naj\u00edt',
	'Replace all': 'Nahradit v\u0161e',
	'Match case': 'Rozli\u0161ovat mal\u00e1 a velk\u00e1 p\u00edsmena',
	Prev: 'P\u0159edchoz\u00ed',
	Spellcheck: 'Kontrola pravopisu',
	Finish: 'Ukon\u010dit',
	'Ignore all': 'Ignorovat v\u0161e',
	Ignore: 'Ignorovat',
	'Add to Dictionary': 'P\u0159idat do slovn\u00edku',
	'Insert row before': 'Vlo\u017eit \u0159\u00e1dek nad',
	Rows: '\u0158\u00e1dek',
	Height: 'V\u00fd\u0161ka',
	'Paste row after': 'Vlo\u017eit \u0159\u00e1dek pod',
	Alignment: 'Zarovn\u00e1n\u00ed',
	'Border color': 'Barva r\u00e1me\u010dku',
	'Column group': 'Skupina sloupc\u016f',
	Row: '\u0158\u00e1dek',
	'Insert column before': 'Vlo\u017eit sloupec vlevo',
	'Split cell': 'Rozd\u011blit bu\u0148ky',
	'Cell padding': 'Vnit\u0159n\u00ed okraj bun\u011bk',
	'Cell spacing': 'Vn\u011bj\u0161\u00ed okraj bun\u011bk',
	'Row type': 'Typ \u0159\u00e1dku',
	'Insert table': 'Vlo\u017eit tabulku',
	Body: 'T\u011blo',
	Caption: 'Nadpis',
	Footer: 'Pati\u010dka',
	'Delete row': 'Smazat \u0159\u00e1dek',
	'Paste row before': 'Vlo\u017eit \u0159\u00e1dek nad',
	Scope: 'Rozsah',
	'Delete table': 'Smazat tabulku',
	'H Align': 'Horizont\u00e1ln\u00ed zarovn\u00e1n\u00ed',
	Top: 'Nahoru',
	'Header cell': 'Hlavi\u010dkov\u00e1 bu\u0148ka',
	Column: 'Sloupec',
	'Row group': 'Skupina \u0159\u00e1dk\u016f',
	Cell: 'Bu\u0148ka',
	Middle: 'Uprost\u0159ed',
	'Cell type': 'Typ bu\u0148ky',
	'Copy row': 'Kop\u00edrovat \u0159\u00e1dek',
	'Row properties': 'Vlastnosti \u0159\u00e1dku',
	'Table properties': 'Vlastnosti tabulky',
	Bottom: 'Dol\u016f',
	'V Align': 'Vertik\u00e1ln\u00ed zarovn\u00e1n\u00ed',
	Header: 'Hlavi\u010dka',
	Right: 'Vpravo',
	'Insert column after': 'Vlo\u017eit sloupec vpravo',
	Cols: 'Sloupc\u016f',
	'Insert row after': 'Vlo\u017eit \u0159\u00e1dek pod',
	Width: '\u0160\u00ed\u0159ka',
	'Cell properties': 'Vlastnosti bu\u0148ky',
	Left: 'Vlevo',
	'Cut row': 'Vyjmout \u0159\u00e1dek',
	'Delete column': 'Smazat sloupec',
	Center: 'Na st\u0159ed',
	'Merge cells': 'Slou\u010dit bu\u0148ky',
	'Insert template': 'Vlo\u017eit \u0161ablonu',
	Templates: '\u0160ablony',
	'Background color': 'Barva pozad\u00ed',
	'Custom...': 'Vlastn\u00ed...',
	'Custom color': 'Vlastn\u00ed barva',
	'No color': 'Bez barvy',
	'Text color': 'Barva p\u00edsma',
	'Show blocks': 'Uk\u00e1zat bloky',
	'Show invisible characters': 'Zobrazit speci\u00e1ln\u00ed znaky',
	'Words: {0}': 'Po\u010det slov: {0}',
	Insert: 'Vlo\u017eit',
	File: 'Soubor',
	Edit: '\u00dapravy',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Editor. Stiskn\u011bte ALT-F9 pro menu, ALT-F10 pro n\u00e1strojovou li\u0161tu a ALT-0 pro n\u00e1pov\u011bdu.',
	Tools: 'N\u00e1stroje',
	View: 'Zobrazit',
	Table: 'Tabulka',
	Format: 'Form\u00e1t',
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/_diffs/langs/cs.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('cs', {
	'Cut': 'Vyjmout',
	'Heading 5': 'Nadpis 5',
	'Header 2': 'Nadpis 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'V\u00e1\u0161 prohl\u00ed\u017ee\u010d nepodporuje p\u0159\u00edm\u00fd p\u0159\u00edstup do schr\u00e1nky. Pou\u017eijte pros\u00edm kl\u00e1vesov\u00e9 zkratky Ctrl+X/C/V.',
	'Heading 4': 'Nadpis 4',
	'Div': 'Div (blok)',
	'Heading 2': 'Nadpis 2',
	'Paste': 'Vlo\u017eit',
	'Close': 'Zav\u0159\u00edt',
	'Font Family': 'Typ p\u00edsma',
	'Pre': 'Pre (p\u0159edform\u00e1tov\u00e1no)',
	'Align right': 'Zarovnat vpravo',
	'New document': 'Nov\u00fd dokument',
	'Blockquote': 'Citace',
	'Numbered list': '\u010c\u00edslov\u00e1n\u00ed',
	'Heading 1': 'Nadpis 1',
	'Headings': 'Nadpisy',
	'Increase indent': 'Zv\u011bt\u0161it odsazen\u00ed',
	'Formats': 'Form\u00e1ty',
	'Headers': 'Nadpisy',
	'Select all': 'Vybrat v\u0161e',
	'Header 3': 'Nadpis 3',
	'Blocks': 'Blokov\u00e9 zobrazen\u00ed (block)',
	'Undo': 'Zp\u011bt',
	'Strikethrough': 'P\u0159e\u0161rktnut\u00e9',
	'Bullet list': 'Odr\u00e1\u017eky',
	'Header 1': 'Nadpis 1',
	'Superscript': 'Horn\u00ed index',
	'Clear formatting': 'Vymazat form\u00e1tov\u00e1n\u00ed',
	'Font Sizes': 'Velikost p\u00edsma',
	'Subscript': 'Doln\u00ed index',
	'Header 6': 'Nadpis 6',
	'Redo': 'Znovu',
	'Paragraph': 'Odstavec',
	'Ok': 'OK',
	'Bold': 'Tu\u010dn\u00e9',
	'Code': 'Code (k\u00f3d)',
	'Italic': 'Kurz\u00edva',
	'Align center': 'Zarovnat na st\u0159ed',
	'Header 5': 'Nadpis 5',
	'Heading 6': 'Nadpis 6',
	'Heading 3': 'Nadpis 3',
	'Decrease indent': 'Zmen\u0161it odsazen\u00ed',
	'Header 4': 'Nadpis 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Je zapnuto vkl\u00e1d\u00e1n\u00ed \u010dist\u00e9ho textu. Dokud nebude tato volba vypnuta, bude ve\u0161ker\u00fd obsah vlo\u017een jako \u010dist\u00fd text.',
	'Underline': 'Podtr\u017een\u00e9',
	'Cancel': 'Zru\u0161it',
	'Justify': 'Zarovnat do bloku',
	'Inline': '\u0158\u00e1dkov\u00e9 zobrazen\u00ed (inline)',
	'Copy': 'Kop\u00edrovat',
	'Align left': 'Zarovnat vlevo',
	'Visual aids': 'Vizu\u00e1ln\u00ed pom\u016fcky',
	'Lower Greek': 'Mal\u00e9 p\u00edsmenkov\u00e1n\u00ed',
	'Square': '\u010ctvere\u010dek',
	'Default': 'V\u00fdchoz\u00ed',
	'Lower Alpha': 'Norm\u00e1ln\u00ed \u010d\u00edslov\u00e1n\u00ed',
	'Circle': 'Kole\u010dko',
	'Disc': 'Punt\u00edk',
	'Upper Alpha': 'velk\u00e9 p\u00edsmenkov\u00e1n\u00ed',
	'Upper Roman': '\u0158\u00edmsk\u00e9 \u010d\u00edslice',
	'Lower Roman': 'Mal\u00e9 \u0159\u00edmsk\u00e9 \u010d\u00edslice',
	'Name': 'N\u00e1zev',
	'Anchor': 'Kotva',
	'You have unsaved changes are you sure you want to navigate away?':
		'M\u00e1te neulo\u017een\u00e9 zm\u011bny. Opravdu chcete opustit str\u00e1nku?',
	'Restore last draft': 'Obnovit posledn\u00ed koncept',
	'Special character': 'Speci\u00e1ln\u00ed znak',
	'Source code': 'Zdrojov\u00fd k\u00f3d',
	'Color': 'Barva',
	'Right to left': 'Zprava doleva',
	'Left to right': 'Zleva doprava',
	'Emoticons': 'Emotikony',
	'Robots': 'Roboti',
	'Document properties': 'Vlastnosti dokumentu',
	'Title': 'Titulek',
	'Keywords': 'Kl\u00ed\u010dov\u00e1 slova',
	'Encoding': 'K\u00f3dov\u00e1n\u00ed',
	'Description': 'Popis',
	'Author': 'Autor',
	'Fullscreen': 'Na celou obrazovku',
	'Horizontal line': 'Vodorovn\u00e1 \u010d\u00e1ra',
	'Horizontal space': 'Horizont\u00e1ln\u00ed mezera',
	'Insert/edit image': 'Vlo\u017eit / upravit obr\u00e1zek',
	'General': 'Obecn\u00e9',
	'Advanced': 'Pokro\u010dil\u00e9',
	'Source': 'URL',
	'Border': 'R\u00e1me\u010dek',
	'Constrain proportions': 'Zachovat proporce',
	'Vertical space': 'Vertik\u00e1ln\u00ed mezera',
	'Image description': 'Popis obr\u00e1zku',
	'Style': 'Styl',
	'Dimensions': 'Rozm\u011bry',
	'Insert image': 'Vlo\u017eit obr\u00e1zek',
	'Insert date/time': 'Vlo\u017eit datum / \u010das',
	'Remove link': 'Odstranit odkaz',
	'Url': 'URL',
	'Text to display': 'Text k zobrazen\u00ed',
	'Anchors': 'Kotvy',
	'Insert link': 'Vlo\u017eit odkaz',
	'New window': 'Nov\u00e9 okno',
	'None': '\u017d\u00e1dn\u00e9',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Zadan\u00e9 URL vypad\u00e1 jako odkaz na jin\u00fd web. Chcete doplnit povinn\u00fd prefix http://?',
	'Target': 'C\u00edl',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Zadan\u00e9 URL vypad\u00e1 jako e-mailov\u00e1 adresa. Chcete doplnit povinn\u00fd prefix mailto:?',
	'Insert/edit link': 'Vlo\u017eit / upravit odkaz',
	'Insert/edit video': 'Vlo\u017eit / upravit video',
	'Poster': 'N\u00e1hled',
	'Alternative source': 'Alternativn\u00ed zdroj',
	'Paste your embed code below:':
		'Vlo\u017ete k\u00f3d pro vlo\u017een\u00ed n\u00ed\u017ee:',
	'Insert video': 'Vlo\u017eit video',
	'Embed': 'Vlo\u017eit',
	'Nonbreaking space': 'Pevn\u00e1 mezera',
	'Page break': 'Konec str\u00e1nky',
	'Paste as text': 'Vlo\u017eit jako \u010dist\u00fd text',
	'Preview': 'N\u00e1hled',
	'Print': 'Tisk',
	'Save': 'Ulo\u017eit',
	'Could not find the specified string.':
		'Zadan\u00fd \u0159et\u011bzec nebyl nalezen.',
	'Replace': 'Nahradit',
	'Next': 'Dal\u0161\u00ed',
	'Whole words': 'Pouze cel\u00e1 slova',
	'Find and replace': 'Naj\u00edt a nahradit',
	'Replace with': 'Nahradit za',
	'Find': 'Naj\u00edt',
	'Replace all': 'Nahradit v\u0161e',
	'Match case': 'Rozli\u0161ovat mal\u00e1 a velk\u00e1 p\u00edsmena',
	'Prev': 'P\u0159edchoz\u00ed',
	'Spellcheck': 'Kontrola pravopisu',
	'Finish': 'Ukon\u010dit',
	'Ignore all': 'Ignorovat v\u0161e',
	'Ignore': 'Ignorovat',
	'Add to Dictionary': 'P\u0159idat do slovn\u00edku',
	'Insert row before': 'Vlo\u017eit \u0159\u00e1dek nad',
	'Rows': '\u0158\u00e1dek',
	'Height': 'V\u00fd\u0161ka',
	'Paste row after': 'Vlo\u017eit \u0159\u00e1dek pod',
	'Alignment': 'Zarovn\u00e1n\u00ed',
	'Border color': 'Barva r\u00e1me\u010dku',
	'Column group': 'Skupina sloupc\u016f',
	'Row': '\u0158\u00e1dek',
	'Insert column before': 'Vlo\u017eit sloupec vlevo',
	'Split cell': 'Rozd\u011blit bu\u0148ky',
	'Cell padding': 'Vnit\u0159n\u00ed okraj bun\u011bk',
	'Cell spacing': 'Vn\u011bj\u0161\u00ed okraj bun\u011bk',
	'Row type': 'Typ \u0159\u00e1dku',
	'Insert table': 'Vlo\u017eit tabulku',
	'Body': 'T\u011blo',
	'Caption': 'Nadpis',
	'Footer': 'Pati\u010dka',
	'Delete row': 'Smazat \u0159\u00e1dek',
	'Paste row before': 'Vlo\u017eit \u0159\u00e1dek nad',
	'Scope': 'Rozsah',
	'Delete table': 'Smazat tabulku',
	'H Align': 'Horizont\u00e1ln\u00ed zarovn\u00e1n\u00ed',
	'Top': 'Nahoru',
	'Header cell': 'Hlavi\u010dkov\u00e1 bu\u0148ka',
	'Column': 'Sloupec',
	'Row group': 'Skupina \u0159\u00e1dk\u016f',
	'Cell': 'Bu\u0148ka',
	'Middle': 'Uprost\u0159ed',
	'Cell type': 'Typ bu\u0148ky',
	'Copy row': 'Kop\u00edrovat \u0159\u00e1dek',
	'Row properties': 'Vlastnosti \u0159\u00e1dku',
	'Table properties': 'Vlastnosti tabulky',
	'Bottom': 'Dol\u016f',
	'V Align': 'Vertik\u00e1ln\u00ed zarovn\u00e1n\u00ed',
	'Header': 'Hlavi\u010dka',
	'Right': 'Vpravo',
	'Insert column after': 'Vlo\u017eit sloupec vpravo',
	'Cols': 'Sloupc\u016f',
	'Insert row after': 'Vlo\u017eit \u0159\u00e1dek pod',
	'Width': '\u0160\u00ed\u0159ka',
	'Cell properties': 'Vlastnosti bu\u0148ky',
	'Left': 'Vlevo',
	'Cut row': 'Vyjmout \u0159\u00e1dek',
	'Delete column': 'Smazat sloupec',
	'Center': 'Na st\u0159ed',
	'Merge cells': 'Slou\u010dit bu\u0148ky',
	'Insert template': 'Vlo\u017eit \u0161ablonu',
	'Templates': '\u0160ablony',
	'Background color': 'Barva pozad\u00ed',
	'Custom...': 'Vlastn\u00ed...',
	'Custom color': 'Vlastn\u00ed barva',
	'No color': 'Bez barvy',
	'Text color': 'Barva p\u00edsma',
	'Show blocks': 'Uk\u00e1zat bloky',
	'Show invisible characters': 'Zobrazit speci\u00e1ln\u00ed znaky',
	'Words: {0}': 'Po\u010det slov: {0}',
	'Insert': 'Vlo\u017eit',
	'File': 'Soubor',
	'Edit': '\u00dapravy',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Editor. Stiskn\u011bte ALT-F9 pro menu, ALT-F10 pro n\u00e1strojovou li\u0161tu a ALT-0 pro n\u00e1pov\u011bdu.',
	'Tools': 'N\u00e1stroje',
	'View': 'Zobrazit',
	'Table': 'Tabulka',
	'Format': 'Form\u00e1t',
});
